``eradiate.units``
==================

.. automodule:: eradiate.units

.. py:currentmodule:: eradiate.units

Attributes
----------

.. autodata:: unit_context_config
   :annotation:

.. autodata:: unit_context_kernel
   :annotation:

.. autodata:: unit_registry
   :annotation:

Enumerations
------------

.. autoclass:: PhysicalQuantity
   :members:
   :no-autosummary:

Functions
-----------------

.. autofunction:: interpret_quantities

.. autofunction:: symbol

.. autofunction:: to_quantity
